@@ -1,8 +1,10 @@
+from authlib.deprecate import deprecate
+
 from .rfc7517 import JsonWebKey
 
 
 def loads(obj, kid=None):
-    # TODO: deprecate
+    deprecate("Please use ``JsonWebKey`` directly.")
     key_set = JsonWebKey.import_key_set(obj)
     if key_set:
         return key_set.find_by_kid(kid)
@@ -10,9 +12,9 @@ def loads(obj, kid=None):
 
 
 def dumps(key, kty=None, **params):
-    # TODO: deprecate
+    deprecate("Please use ``JsonWebKey`` directly.")
     if kty:
-        params['kty'] = kty
+        params["kty"] = kty
 
     key = JsonWebKey.import_key(key, params)
     return dict(key)
