@@ -2,15 +2,15 @@ import os
 from abc import ABCMeta
 
 
-class JWEAlgorithmBase(metaclass=ABCMeta):
-    """Base interface for all JWE algorithms.
-    """
+class JWEAlgorithmBase(metaclass=ABCMeta):  # noqa: B024
+    """Base interface for all JWE algorithms."""
+
     EXTRA_HEADERS = None
 
     name = None
     description = None
-    algorithm_type = 'JWE'
-    algorithm_location = 'alg'
+    algorithm_type = "JWE"
+    algorithm_location = "alg"
 
     def prepare_key(self, raw_data):
         raise NotImplementedError
@@ -21,8 +21,10 @@ class JWEAlgorithmBase(metaclass=ABCMeta):
 
 class JWEAlgorithm(JWEAlgorithmBase, metaclass=ABCMeta):
     """Interface for JWE algorithm conforming to RFC7518.
-    JWA specification (RFC7518) SHOULD implement the algorithms for JWE with this base implementation.
+    JWA specification (RFC7518) SHOULD implement the algorithms for JWE
+    with this base implementation.
     """
+
     def wrap(self, enc_alg, headers, key, preset=None):
         raise NotImplementedError
 
@@ -31,13 +33,17 @@ class JWEAlgorithm(JWEAlgorithmBase, metaclass=ABCMeta):
 
 
 class JWEAlgorithmWithTagAwareKeyAgreement(JWEAlgorithmBase, metaclass=ABCMeta):
-    """Interface for JWE algorithm with tag-aware key agreement (in key agreement with key wrapping mode).
+    """Interface for JWE algorithm with tag-aware key agreement (in key agreement
+    with key wrapping mode).
     ECDH-1PU is an example of such an algorithm.
     """
+
     def generate_keys_and_prepare_headers(self, enc_alg, key, sender_key, preset=None):
         raise NotImplementedError
 
-    def agree_upon_key_and_wrap_cek(self, enc_alg, headers, key, sender_key, epk, cek, tag):
+    def agree_upon_key_and_wrap_cek(
+        self, enc_alg, headers, key, sender_key, epk, cek, tag
+    ):
         raise NotImplementedError
 
     def wrap(self, enc_alg, headers, key, sender_key, preset=None):
@@ -50,8 +56,8 @@ class JWEAlgorithmWithTagAwareKeyAgreement(JWEAlgorithmBase, metaclass=ABCMeta):
 class JWEEncAlgorithm:
     name = None
     description = None
-    algorithm_type = 'JWE'
-    algorithm_location = 'enc'
+    algorithm_type = "JWE"
+    algorithm_location = "enc"
 
     IV_SIZE = None
     CEK_SIZE = None
@@ -93,8 +99,8 @@ class JWEEncAlgorithm:
 class JWEZipAlgorithm:
     name = None
     description = None
-    algorithm_type = 'JWE'
-    algorithm_location = 'zip'
+    algorithm_type = "JWE"
+    algorithm_location = "zip"
 
     def compress(self, s):
         raise NotImplementedError
@@ -108,6 +114,7 @@ class JWESharedHeader(dict):
 
     Combines protected header and shared unprotected header together.
     """
+
     def __init__(self, protected, unprotected):
         obj = {}
         if protected:
@@ -126,14 +133,16 @@ class JWESharedHeader(dict):
     def from_dict(cls, obj):
         if isinstance(obj, cls):
             return obj
-        return cls(obj.get('protected'), obj.get('unprotected'))
+        return cls(obj.get("protected"), obj.get("unprotected"))
 
 
 class JWEHeader(dict):
     """Header object for JWE.
 
-    Combines protected header, shared unprotected header and specific recipient's unprotected header together.
+    Combines protected header, shared unprotected header
+    and specific recipient's unprotected header together.
     """
+
     def __init__(self, protected, unprotected, header):
         obj = {}
         if protected:
