@@ -3,6 +3,8 @@ from copy import deepcopy
 from unittest import TestCase
 from unittest import mock
 
+import pytest
+
 from authlib.common.security import generate_token
 from authlib.common.urls import add_params_to_uri
 from authlib.common.urls import url_encode
@@ -57,14 +59,15 @@ class OAuth2SessionTest(TestCase):
             "expires_at": int(time.time()) + 3600,
         }
         with OAuth2Session(self.client_id, token=token) as sess:
-            self.assertRaises(OAuthError, sess.get, "https://i.b")
+            with pytest.raises(OAuthError):
+                sess.get("https://i.b")
 
     def test_add_token_to_header(self):
         token = "Bearer " + self.token["access_token"]
 
         def verifier(r, **kwargs):
             auth_header = r.headers.get("Authorization", None)
-            self.assertEqual(auth_header, token)
+            assert auth_header == token
             resp = mock.MagicMock()
             return resp
 
@@ -74,7 +77,7 @@ class OAuth2SessionTest(TestCase):
 
     def test_add_token_to_body(self):
         def verifier(r, **kwargs):
-            self.assertIn(self.token["access_token"], r.body)
+            assert self.token["access_token"] in r.body
             resp = mock.MagicMock()
             return resp
 
@@ -86,7 +89,7 @@ class OAuth2SessionTest(TestCase):
 
     def test_add_token_to_uri(self):
         def verifier(r, **kwargs):
-            self.assertIn(self.token["access_token"], r.url)
+            assert self.token["access_token"] in r.url
             resp = mock.MagicMock()
             return resp
 
@@ -101,18 +104,18 @@ class OAuth2SessionTest(TestCase):
 
         sess = OAuth2Session(client_id=self.client_id)
         auth_url, state = sess.create_authorization_url(url)
-        self.assertIn(state, auth_url)
-        self.assertIn(self.client_id, auth_url)
-        self.assertIn("response_type=code", auth_url)
+        assert state in auth_url
+        assert self.client_id in auth_url
+        assert "response_type=code" in auth_url
 
         sess = OAuth2Session(client_id=self.client_id, prompt="none")
         auth_url, state = sess.create_authorization_url(
             url, state="foo", redirect_uri="https://i.b", scope="profile"
         )
-        self.assertEqual(state, "foo")
-        self.assertIn("i.b", auth_url)
-        self.assertIn("profile", auth_url)
-        self.assertIn("prompt=none", auth_url)
+        assert state == "foo"
+        assert "i.b" in auth_url
+        assert "profile" in auth_url
+        assert "prompt=none" in auth_url
 
     def test_code_challenge(self):
         sess = OAuth2Session(client_id=self.client_id, code_challenge_method="S256")
@@ -121,23 +124,23 @@ class OAuth2SessionTest(TestCase):
         auth_url, _ = sess.create_authorization_url(
             url, code_verifier=generate_token(48)
         )
-        self.assertIn("code_challenge", auth_url)
-        self.assertIn("code_challenge_method=S256", auth_url)
+        assert "code_challenge" in auth_url
+        assert "code_challenge_method=S256" in auth_url
 
     def test_token_from_fragment(self):
         sess = OAuth2Session(self.client_id)
         response_url = "https://i.b/callback#" + url_encode(self.token.items())
-        self.assertEqual(sess.token_from_fragment(response_url), self.token)
+        assert sess.token_from_fragment(response_url) == self.token
         token = sess.fetch_token(authorization_response=response_url)
-        self.assertEqual(token, self.token)
+        assert token == self.token
 
     def test_fetch_token_post(self):
         url = "https://example.com/token"
 
         def fake_send(r, **kwargs):
-            self.assertIn("code=v", r.body)
-            self.assertIn("client_id=", r.body)
-            self.assertIn("grant_type=authorization_code", r.body)
+            assert "code=v" in r.body
+            assert "client_id=" in r.body
+            assert "grant_type=authorization_code" in r.body
             resp = mock.MagicMock()
             resp.status_code = 200
             resp.json = lambda: self.token
@@ -145,9 +148,9 @@ class OAuth2SessionTest(TestCase):
 
         sess = OAuth2Session(client_id=self.client_id)
         sess.send = fake_send
-        self.assertEqual(
-            sess.fetch_token(url, authorization_response="https://i.b/?code=v"),
-            self.token,
+        assert (
+            sess.fetch_token(url, authorization_response="https://i.b/?code=v")
+            == self.token
         )
 
         sess = OAuth2Session(
@@ -156,19 +159,20 @@ class OAuth2SessionTest(TestCase):
         )
         sess.send = fake_send
         token = sess.fetch_token(url, code="v")
-        self.assertEqual(token, self.token)
+        assert token == self.token
 
         error = {"error": "invalid_request"}
         sess = OAuth2Session(client_id=self.client_id, token=self.token)
         sess.send = mock_json_response(error)
-        self.assertRaises(OAuthError, sess.fetch_access_token, url)
+        with pytest.raises(OAuthError):
+            sess.fetch_access_token(url)
 
     def test_fetch_token_get(self):
         url = "https://example.com/token"
 
         def fake_send(r, **kwargs):
-            self.assertIn("code=v", r.url)
-            self.assertIn("grant_type=authorization_code", r.url)
+            assert "code=v" in r.url
+            assert "grant_type=authorization_code" in r.url
             resp = mock.MagicMock()
             resp.status_code = 200
             resp.json = lambda: self.token
@@ -179,7 +183,7 @@ class OAuth2SessionTest(TestCase):
         token = sess.fetch_token(
             url, authorization_response="https://i.b/?code=v", method="GET"
         )
-        self.assertEqual(token, self.token)
+        assert token == self.token
 
         sess = OAuth2Session(
             client_id=self.client_id,
@@ -187,19 +191,19 @@ class OAuth2SessionTest(TestCase):
         )
         sess.send = fake_send
         token = sess.fetch_token(url, code="v", method="GET")
-        self.assertEqual(token, self.token)
+        assert token == self.token
 
         token = sess.fetch_token(url + "?q=a", code="v", method="GET")
-        self.assertEqual(token, self.token)
+        assert token == self.token
 
     def test_token_auth_method_client_secret_post(self):
         url = "https://example.com/token"
 
         def fake_send(r, **kwargs):
-            self.assertIn("code=v", r.body)
-            self.assertIn("client_id=", r.body)
-            self.assertIn("client_secret=bar", r.body)
-            self.assertIn("grant_type=authorization_code", r.body)
+            assert "code=v" in r.body
+            assert "client_id=" in r.body
+            assert "client_secret=bar" in r.body
+            assert "grant_type=authorization_code" in r.body
             resp = mock.MagicMock()
             resp.status_code = 200
             resp.json = lambda: self.token
@@ -212,13 +216,13 @@ class OAuth2SessionTest(TestCase):
         )
         sess.send = fake_send
         token = sess.fetch_token(url, code="v")
-        self.assertEqual(token, self.token)
+        assert token == self.token
 
     def test_access_token_response_hook(self):
         url = "https://example.com/token"
 
         def access_token_response_hook(resp):
-            self.assertEqual(resp.json(), self.token)
+            assert resp.json() == self.token
             return resp
 
         sess = OAuth2Session(client_id=self.client_id, token=self.token)
@@ -226,15 +230,15 @@ class OAuth2SessionTest(TestCase):
             "access_token_response", access_token_response_hook
         )
         sess.send = mock_json_response(self.token)
-        self.assertEqual(sess.fetch_token(url), self.token)
+        assert sess.fetch_token(url) == self.token
 
     def test_password_grant_type(self):
         url = "https://example.com/token"
 
         def fake_send(r, **kwargs):
-            self.assertIn("username=v", r.body)
-            self.assertIn("grant_type=password", r.body)
-            self.assertIn("scope=profile", r.body)
+            assert "username=v" in r.body
+            assert "grant_type=password" in r.body
+            assert "scope=profile" in r.body
             resp = mock.MagicMock()
             resp.status_code = 200
             resp.json = lambda: self.token
@@ -243,14 +247,14 @@ class OAuth2SessionTest(TestCase):
         sess = OAuth2Session(client_id=self.client_id, scope="profile")
         sess.send = fake_send
         token = sess.fetch_token(url, username="v", password="v")
-        self.assertEqual(token, self.token)
+        assert token == self.token
 
     def test_client_credentials_type(self):
         url = "https://example.com/token"
 
         def fake_send(r, **kwargs):
-            self.assertIn("grant_type=client_credentials", r.body)
-            self.assertIn("scope=profile", r.body)
+            assert "grant_type=client_credentials" in r.body
+            assert "scope=profile" in r.body
             resp = mock.MagicMock()
             resp.status_code = 200
             resp.json = lambda: self.token
@@ -263,7 +267,7 @@ class OAuth2SessionTest(TestCase):
         )
         sess.send = fake_send
         token = sess.fetch_token(url)
-        self.assertEqual(token, self.token)
+        assert token == self.token
 
     def test_cleans_previous_token_before_fetching_new_one(self):
         """Makes sure the previous token is cleaned before fetching a new one.
@@ -281,64 +285,60 @@ class OAuth2SessionTest(TestCase):
         with mock.patch("time.time", lambda: now):
             sess = OAuth2Session(client_id=self.client_id, token=self.token)
             sess.send = mock_json_response(new_token)
-            self.assertEqual(sess.fetch_token(url), new_token)
+            assert sess.fetch_token(url) == new_token
 
     def test_mis_match_state(self):
         sess = OAuth2Session("foo")
-        self.assertRaises(
-            MismatchingStateException,
-            sess.fetch_token,
-            "https://i.b/token",
-            authorization_response="https://i.b/no-state?code=abc",
-            state="somestate",
-        )
+        with pytest.raises(MismatchingStateException):
+            sess.fetch_token(
+                "https://i.b/token",
+                authorization_response="https://i.b/no-state?code=abc",
+                state="somestate",
+            )
 
     def test_token_status(self):
         token = dict(access_token="a", token_type="bearer", expires_at=100)
         sess = OAuth2Session("foo", token=token)
 
-        self.assertTrue(sess.token.is_expired)
+        assert sess.token.is_expired
 
     def test_token_status2(self):
         token = dict(access_token="a", token_type="bearer", expires_in=10)
         sess = OAuth2Session("foo", token=token, leeway=15)
 
-        self.assertTrue(sess.token.is_expired(sess.leeway))
+        assert sess.token.is_expired(sess.leeway)
 
     def test_token_status3(self):
         token = dict(access_token="a", token_type="bearer", expires_in=10)
         sess = OAuth2Session("foo", token=token, leeway=5)
 
-        self.assertFalse(sess.token.is_expired(sess.leeway))
+        assert not sess.token.is_expired(sess.leeway)
 
     def test_token_expired(self):
         token = dict(access_token="a", token_type="bearer", expires_at=100)
         sess = OAuth2Session("foo", token=token)
-        self.assertRaises(
-            OAuthError,
-            sess.get,
-            "https://i.b/token",
-        )
+        with pytest.raises(OAuthError):
+            sess.get(
+                "https://i.b/token",
+            )
 
     def test_missing_token(self):
         sess = OAuth2Session("foo")
-        self.assertRaises(
-            OAuthError,
-            sess.get,
-            "https://i.b/token",
-        )
+        with pytest.raises(OAuthError):
+            sess.get(
+                "https://i.b/token",
+            )
 
     def test_register_compliance_hook(self):
         sess = OAuth2Session("foo")
-        self.assertRaises(
-            ValueError,
-            sess.register_compliance_hook,
-            "invalid_hook",
-            lambda o: o,
-        )
+        with pytest.raises(ValueError):
+            sess.register_compliance_hook(
+                "invalid_hook",
+                lambda o: o,
+            )
 
         def protected_request(url, headers, data):
-            self.assertIn("Authorization", headers)
+            assert "Authorization" in headers
             return url, headers, data
 
         sess = OAuth2Session("foo", token=self.token)
@@ -351,8 +351,8 @@ class OAuth2SessionTest(TestCase):
 
     def test_auto_refresh_token(self):
         def _update_token(token, refresh_token=None, access_token=None):
-            self.assertEqual(refresh_token, "b")
-            self.assertEqual(token, self.token)
+            assert refresh_token == "b"
+            assert token == self.token
 
         update_token = mock.Mock(side_effect=_update_token)
         old_token = dict(
@@ -366,12 +366,12 @@ class OAuth2SessionTest(TestCase):
         )
         sess.send = mock_json_response(self.token)
         sess.get("https://i.b/user")
-        self.assertTrue(update_token.called)
+        assert update_token.called
 
     def test_auto_refresh_token2(self):
         def _update_token(token, refresh_token=None, access_token=None):
-            self.assertEqual(access_token, "a")
-            self.assertEqual(token, self.token)
+            assert access_token == "a"
+            assert token == self.token
 
         update_token = mock.Mock(side_effect=_update_token)
         old_token = dict(access_token="a", token_type="bearer", expires_at=100)
@@ -384,7 +384,7 @@ class OAuth2SessionTest(TestCase):
         )
         sess.send = mock_json_response(self.token)
         sess.get("https://i.b/user")
-        self.assertFalse(update_token.called)
+        assert not update_token.called
 
         sess = OAuth2Session(
             "foo",
@@ -395,21 +395,21 @@ class OAuth2SessionTest(TestCase):
         )
         sess.send = mock_json_response(self.token)
         sess.get("https://i.b/user")
-        self.assertTrue(update_token.called)
+        assert update_token.called
 
     def test_revoke_token(self):
         sess = OAuth2Session("a")
         answer = {"status": "ok"}
         sess.send = mock_json_response(answer)
         resp = sess.revoke_token("https://i.b/token", "hi")
-        self.assertEqual(resp.json(), answer)
+        assert resp.json() == answer
         resp = sess.revoke_token(
             "https://i.b/token", "hi", token_type_hint="access_token"
         )
-        self.assertEqual(resp.json(), answer)
+        assert resp.json() == answer
 
         def revoke_token_request(url, headers, data):
-            self.assertEqual(url, "https://i.b/token")
+            assert url == "https://i.b/token"
             return url, headers, data
 
         sess.register_compliance_hook(
@@ -435,7 +435,7 @@ class OAuth2SessionTest(TestCase):
         }
         sess.send = mock_json_response(answer)
         resp = sess.introspect_token("https://i.b/token", "hi")
-        self.assertEqual(resp.json(), answer)
+        assert resp.json() == answer
 
     def test_client_secret_jwt(self):
         sess = OAuth2Session(
@@ -445,7 +445,7 @@ class OAuth2SessionTest(TestCase):
 
         mock_assertion_response(self, sess)
         token = sess.fetch_token("https://i.b/token")
-        self.assertEqual(token, self.token)
+        assert token == self.token
 
     def test_client_secret_jwt2(self):
         sess = OAuth2Session(
@@ -455,7 +455,7 @@ class OAuth2SessionTest(TestCase):
         )
         mock_assertion_response(self, sess)
         token = sess.fetch_token("https://i.b/token")
-        self.assertEqual(token, self.token)
+        assert token == self.token
 
     def test_private_key_jwt(self):
         client_secret = read_key_file("rsa_private.pem")
@@ -465,7 +465,7 @@ class OAuth2SessionTest(TestCase):
         sess.register_client_auth_method(PrivateKeyJWT())
         mock_assertion_response(self, sess)
         token = sess.fetch_token("https://i.b/token")
-        self.assertEqual(token, self.token)
+        assert token == self.token
 
     def test_custom_client_auth_method(self):
         def auth_client(client, method, uri, headers, body):
@@ -486,8 +486,8 @@ class OAuth2SessionTest(TestCase):
         sess.register_client_auth_method(("client_secret_uri", auth_client))
 
         def fake_send(r, **kwargs):
-            self.assertIn("client_id=", r.url)
-            self.assertIn("client_secret=", r.url)
+            assert "client_id=" in r.url
+            assert "client_secret=" in r.url
             resp = mock.MagicMock()
             resp.status_code = 200
             resp.json = lambda: self.token
@@ -495,7 +495,7 @@ class OAuth2SessionTest(TestCase):
 
         sess.send = fake_send
         token = sess.fetch_token("https://i.b/token")
-        self.assertEqual(token, self.token)
+        assert token == self.token
 
     def test_use_client_token_auth(self):
         import requests
@@ -504,7 +504,7 @@ class OAuth2SessionTest(TestCase):
 
         def verifier(r, **kwargs):
             auth_header = r.headers.get("Authorization", None)
-            self.assertEqual(auth_header, token)
+            assert auth_header == token
             resp = mock.MagicMock()
             return resp
 
@@ -519,7 +519,7 @@ class OAuth2SessionTest(TestCase):
 
         def verifier(r, **kwargs):
             timeout = kwargs.get("timeout")
-            self.assertEqual(timeout, expected_timeout)
+            assert timeout == expected_timeout
             resp = mock.MagicMock()
             return resp
 
@@ -538,7 +538,7 @@ class OAuth2SessionTest(TestCase):
 
         def verifier(r, **kwargs):
             timeout = kwargs.get("timeout")
-            self.assertEqual(timeout, expected_timeout)
+            assert timeout == expected_timeout
             resp = mock.MagicMock()
             return resp
 
