@@ -1,5 +1,7 @@
 import unittest
 
+import pytest
+
 from authlib.oauth2.rfc8414 import AuthorizationServerMetadata
 from authlib.oauth2.rfc8414 import get_well_known_url
 
@@ -8,58 +10,54 @@ WELL_KNOWN_URL = "/.well-known/oauth-authorization-server"
 
 class WellKnownTest(unittest.TestCase):
     def test_no_suffix_issuer(self):
-        self.assertEqual(get_well_known_url("https://authlib.org"), WELL_KNOWN_URL)
-        self.assertEqual(get_well_known_url("https://authlib.org/"), WELL_KNOWN_URL)
+        assert get_well_known_url("https://authlib.org") == WELL_KNOWN_URL
+        assert get_well_known_url("https://authlib.org/") == WELL_KNOWN_URL
 
     def test_with_suffix_issuer(self):
-        self.assertEqual(
-            get_well_known_url("https://authlib.org/issuer1"),
-            WELL_KNOWN_URL + "/issuer1",
+        assert (
+            get_well_known_url("https://authlib.org/issuer1")
+            == WELL_KNOWN_URL + "/issuer1"
         )
-        self.assertEqual(
-            get_well_known_url("https://authlib.org/a/b/c"), WELL_KNOWN_URL + "/a/b/c"
+        assert (
+            get_well_known_url("https://authlib.org/a/b/c") == WELL_KNOWN_URL + "/a/b/c"
         )
 
     def test_with_external(self):
-        self.assertEqual(
-            get_well_known_url("https://authlib.org", external=True),
-            "https://authlib.org" + WELL_KNOWN_URL,
+        assert (
+            get_well_known_url("https://authlib.org", external=True)
+            == "https://authlib.org" + WELL_KNOWN_URL
         )
 
     def test_with_changed_suffix(self):
         url = get_well_known_url("https://authlib.org", suffix="openid-configuration")
-        self.assertEqual(url, "/.well-known/openid-configuration")
+        assert url == "/.well-known/openid-configuration"
         url = get_well_known_url(
             "https://authlib.org", external=True, suffix="openid-configuration"
         )
-        self.assertEqual(url, "https://authlib.org/.well-known/openid-configuration")
+        assert url == "https://authlib.org/.well-known/openid-configuration"
 
 
 class AuthorizationServerMetadataTest(unittest.TestCase):
     def test_validate_issuer(self):
         #: missing
         metadata = AuthorizationServerMetadata({})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match='"issuer" is required'):
             metadata.validate()
-        self.assertEqual('"issuer" is required', str(cm.exception))
 
         #: https
         metadata = AuthorizationServerMetadata({"issuer": "http://authlib.org/"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="https"):
             metadata.validate_issuer()
-        self.assertIn("https", str(cm.exception))
 
         #: query
         metadata = AuthorizationServerMetadata({"issuer": "https://authlib.org/?a=b"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="query"):
             metadata.validate_issuer()
-        self.assertIn("query", str(cm.exception))
 
         #: fragment
         metadata = AuthorizationServerMetadata({"issuer": "https://authlib.org/#a=b"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="fragment"):
             metadata.validate_issuer()
-        self.assertIn("fragment", str(cm.exception))
 
         metadata = AuthorizationServerMetadata({"issuer": "https://authlib.org/"})
         metadata.validate_issuer()
@@ -69,9 +67,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata = AuthorizationServerMetadata(
             {"authorization_endpoint": "http://authlib.org/"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="https"):
             metadata.validate_authorization_endpoint()
-        self.assertIn("https", str(cm.exception))
 
         # valid https
         metadata = AuthorizationServerMetadata(
@@ -81,9 +78,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
 
         # missing
         metadata = AuthorizationServerMetadata()
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="required"):
             metadata.validate_authorization_endpoint()
-        self.assertIn("required", str(cm.exception))
 
         # valid missing
         metadata = AuthorizationServerMetadata({"grant_types_supported": ["password"]})
@@ -96,17 +92,15 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
 
         # missing
         metadata = AuthorizationServerMetadata()
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="required"):
             metadata.validate_token_endpoint()
-        self.assertIn("required", str(cm.exception))
 
         # https
         metadata = AuthorizationServerMetadata(
             {"token_endpoint": "http://authlib.org/"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="https"):
             metadata.validate_token_endpoint()
-        self.assertIn("https", str(cm.exception))
 
         # valid
         metadata = AuthorizationServerMetadata(
@@ -122,9 +116,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata = AuthorizationServerMetadata(
             {"jwks_uri": "http://authlib.org/jwks.json"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="https"):
             metadata.validate_jwks_uri()
-        self.assertIn("https", str(cm.exception))
 
         metadata = AuthorizationServerMetadata(
             {"jwks_uri": "https://authlib.org/jwks.json"}
@@ -138,9 +131,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata = AuthorizationServerMetadata(
             {"registration_endpoint": "http://authlib.org/"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="https"):
             metadata.validate_registration_endpoint()
-        self.assertIn("https", str(cm.exception))
 
         metadata = AuthorizationServerMetadata(
             {"registration_endpoint": "https://authlib.org/"}
@@ -153,9 +145,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
 
         # not array
         metadata = AuthorizationServerMetadata({"scopes_supported": "foo"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             metadata.validate_scopes_supported()
-        self.assertIn("JSON array", str(cm.exception))
 
         # valid
         metadata = AuthorizationServerMetadata({"scopes_supported": ["foo"]})
@@ -164,15 +155,13 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
     def test_validate_response_types_supported(self):
         # missing
         metadata = AuthorizationServerMetadata()
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="required"):
             metadata.validate_response_types_supported()
-        self.assertIn("required", str(cm.exception))
 
         # not array
         metadata = AuthorizationServerMetadata({"response_types_supported": "code"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             metadata.validate_response_types_supported()
-        self.assertIn("JSON array", str(cm.exception))
 
         # valid
         metadata = AuthorizationServerMetadata({"response_types_supported": ["code"]})
@@ -184,9 +173,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
 
         # not array
         metadata = AuthorizationServerMetadata({"response_modes_supported": "query"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             metadata.validate_response_modes_supported()
-        self.assertIn("JSON array", str(cm.exception))
 
         # valid
         metadata = AuthorizationServerMetadata({"response_modes_supported": ["query"]})
@@ -198,9 +186,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
 
         # not array
         metadata = AuthorizationServerMetadata({"grant_types_supported": "password"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             metadata.validate_grant_types_supported()
-        self.assertIn("JSON array", str(cm.exception))
 
         # valid
         metadata = AuthorizationServerMetadata({"grant_types_supported": ["password"]})
@@ -214,9 +201,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata = AuthorizationServerMetadata(
             {"token_endpoint_auth_methods_supported": "client_secret_basic"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             metadata.validate_token_endpoint_auth_methods_supported()
-        self.assertIn("JSON array", str(cm.exception))
 
         # valid
         metadata = AuthorizationServerMetadata(
@@ -231,16 +217,14 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata = AuthorizationServerMetadata(
             {"token_endpoint_auth_methods_supported": ["client_secret_jwt"]}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="required"):
             metadata.validate_token_endpoint_auth_signing_alg_values_supported()
-        self.assertIn("required", str(cm.exception))
 
         metadata = AuthorizationServerMetadata(
             {"token_endpoint_auth_signing_alg_values_supported": "RS256"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             metadata.validate_token_endpoint_auth_signing_alg_values_supported()
-        self.assertIn("JSON array", str(cm.exception))
 
         metadata = AuthorizationServerMetadata(
             {
@@ -248,18 +232,16 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
                 "token_endpoint_auth_signing_alg_values_supported": ["RS256", "none"],
             }
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="none"):
             metadata.validate_token_endpoint_auth_signing_alg_values_supported()
-        self.assertIn("none", str(cm.exception))
 
     def test_validate_service_documentation(self):
         metadata = AuthorizationServerMetadata()
         metadata.validate_service_documentation()
 
         metadata = AuthorizationServerMetadata({"service_documentation": "invalid"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="MUST be a URL"):
             metadata.validate_service_documentation()
-        self.assertIn("MUST be a URL", str(cm.exception))
 
         metadata = AuthorizationServerMetadata(
             {"service_documentation": "https://authlib.org/"}
@@ -272,9 +254,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
 
         # not array
         metadata = AuthorizationServerMetadata({"ui_locales_supported": "en"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             metadata.validate_ui_locales_supported()
-        self.assertIn("JSON array", str(cm.exception))
 
         # valid
         metadata = AuthorizationServerMetadata({"ui_locales_supported": ["en"]})
@@ -285,9 +266,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata.validate_op_policy_uri()
 
         metadata = AuthorizationServerMetadata({"op_policy_uri": "invalid"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="MUST be a URL"):
             metadata.validate_op_policy_uri()
-        self.assertIn("MUST be a URL", str(cm.exception))
 
         metadata = AuthorizationServerMetadata(
             {"op_policy_uri": "https://authlib.org/"}
@@ -299,9 +279,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata.validate_op_tos_uri()
 
         metadata = AuthorizationServerMetadata({"op_tos_uri": "invalid"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="MUST be a URL"):
             metadata.validate_op_tos_uri()
-        self.assertIn("MUST be a URL", str(cm.exception))
 
         metadata = AuthorizationServerMetadata({"op_tos_uri": "https://authlib.org/"})
         metadata.validate_op_tos_uri()
@@ -314,9 +293,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata = AuthorizationServerMetadata(
             {"revocation_endpoint": "http://authlib.org/"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="https"):
             metadata.validate_revocation_endpoint()
-        self.assertIn("https", str(cm.exception))
 
         # valid
         metadata = AuthorizationServerMetadata(
@@ -332,9 +310,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata = AuthorizationServerMetadata(
             {"revocation_endpoint_auth_methods_supported": "client_secret_basic"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             metadata.validate_revocation_endpoint_auth_methods_supported()
-        self.assertIn("JSON array", str(cm.exception))
 
         # valid
         metadata = AuthorizationServerMetadata(
@@ -349,16 +326,14 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata = AuthorizationServerMetadata(
             {"revocation_endpoint_auth_methods_supported": ["client_secret_jwt"]}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="required"):
             metadata.validate_revocation_endpoint_auth_signing_alg_values_supported()
-        self.assertIn("required", str(cm.exception))
 
         metadata = AuthorizationServerMetadata(
             {"revocation_endpoint_auth_signing_alg_values_supported": "RS256"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             metadata.validate_revocation_endpoint_auth_signing_alg_values_supported()
-        self.assertIn("JSON array", str(cm.exception))
 
         metadata = AuthorizationServerMetadata(
             {
@@ -369,9 +344,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
                 ],
             }
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="none"):
             metadata.validate_revocation_endpoint_auth_signing_alg_values_supported()
-        self.assertIn("none", str(cm.exception))
 
     def test_validate_introspection_endpoint(self):
         metadata = AuthorizationServerMetadata()
@@ -381,9 +355,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata = AuthorizationServerMetadata(
             {"introspection_endpoint": "http://authlib.org/"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="https"):
             metadata.validate_introspection_endpoint()
-        self.assertIn("https", str(cm.exception))
 
         # valid
         metadata = AuthorizationServerMetadata(
@@ -399,9 +372,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata = AuthorizationServerMetadata(
             {"introspection_endpoint_auth_methods_supported": "client_secret_basic"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             metadata.validate_introspection_endpoint_auth_methods_supported()
-        self.assertIn("JSON array", str(cm.exception))
 
         # valid
         metadata = AuthorizationServerMetadata(
@@ -416,16 +388,14 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata = AuthorizationServerMetadata(
             {"introspection_endpoint_auth_methods_supported": ["client_secret_jwt"]}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="required"):
             metadata.validate_introspection_endpoint_auth_signing_alg_values_supported()
-        self.assertIn("required", str(cm.exception))
 
         metadata = AuthorizationServerMetadata(
             {"introspection_endpoint_auth_signing_alg_values_supported": "RS256"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             metadata.validate_introspection_endpoint_auth_signing_alg_values_supported()
-        self.assertIn("JSON array", str(cm.exception))
 
         metadata = AuthorizationServerMetadata(
             {
@@ -436,9 +406,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
                 ],
             }
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="none"):
             metadata.validate_introspection_endpoint_auth_signing_alg_values_supported()
-        self.assertIn("none", str(cm.exception))
 
     def test_validate_code_challenge_methods_supported(self):
         metadata = AuthorizationServerMetadata()
@@ -448,9 +417,8 @@ class AuthorizationServerMetadataTest(unittest.TestCase):
         metadata = AuthorizationServerMetadata(
             {"code_challenge_methods_supported": "S256"}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             metadata.validate_code_challenge_methods_supported()
-        self.assertIn("JSON array", str(cm.exception))
 
         # valid
         metadata = AuthorizationServerMetadata(
