@@ -1,5 +1,7 @@
 import unittest
 
+import pytest
+
 from authlib.oidc.discovery import OpenIDProviderMetadata
 from authlib.oidc.discovery import get_well_known_url
 
@@ -8,22 +10,22 @@ WELL_KNOWN_URL = "/.well-known/openid-configuration"
 
 class WellKnownTest(unittest.TestCase):
     def test_no_suffix_issuer(self):
-        self.assertEqual(get_well_known_url("https://authlib.org"), WELL_KNOWN_URL)
-        self.assertEqual(get_well_known_url("https://authlib.org/"), WELL_KNOWN_URL)
+        assert get_well_known_url("https://authlib.org") == WELL_KNOWN_URL
+        assert get_well_known_url("https://authlib.org/") == WELL_KNOWN_URL
 
     def test_with_suffix_issuer(self):
-        self.assertEqual(
-            get_well_known_url("https://authlib.org/issuer1"),
-            "/issuer1" + WELL_KNOWN_URL,
+        assert (
+            get_well_known_url("https://authlib.org/issuer1")
+            == "/issuer1" + WELL_KNOWN_URL
         )
-        self.assertEqual(
-            get_well_known_url("https://authlib.org/a/b/c"), "/a/b/c" + WELL_KNOWN_URL
+        assert (
+            get_well_known_url("https://authlib.org/a/b/c") == "/a/b/c" + WELL_KNOWN_URL
         )
 
     def test_with_external(self):
-        self.assertEqual(
-            get_well_known_url("https://authlib.org", external=True),
-            "https://authlib.org" + WELL_KNOWN_URL,
+        assert (
+            get_well_known_url("https://authlib.org", external=True)
+            == "https://authlib.org" + WELL_KNOWN_URL
         )
 
 
@@ -31,14 +33,12 @@ class OpenIDProviderMetadataTest(unittest.TestCase):
     def test_validate_jwks_uri(self):
         # required
         metadata = OpenIDProviderMetadata()
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match='"jwks_uri" is required'):
             metadata.validate_jwks_uri()
-        self.assertEqual('"jwks_uri" is required', str(cm.exception))
 
         metadata = OpenIDProviderMetadata({"jwks_uri": "http://authlib.org/jwks.json"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="https"):
             metadata.validate_jwks_uri()
-        self.assertIn("https", str(cm.exception))
 
         metadata = OpenIDProviderMetadata({"jwks_uri": "https://authlib.org/jwks.json"})
         metadata.validate_jwks_uri()
@@ -63,9 +63,8 @@ class OpenIDProviderMetadataTest(unittest.TestCase):
         metadata = OpenIDProviderMetadata(
             {"id_token_signing_alg_values_supported": ["none"]}
         )
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="RS256"):
             metadata.validate_id_token_signing_alg_values_supported()
-        self.assertIn("RS256", str(cm.exception))
 
     def test_validate_id_token_encryption_alg_values_supported(self):
         self._call_validate_array(
@@ -94,12 +93,6 @@ class OpenIDProviderMetadataTest(unittest.TestCase):
         self._call_validate_array(
             "request_object_signing_alg_values_supported", ["none", "RS256"]
         )
-        metadata = OpenIDProviderMetadata(
-            {"request_object_signing_alg_values_supported": ["RS512"]}
-        )
-        with self.assertRaises(ValueError) as cm:
-            metadata.validate_request_object_signing_alg_values_supported()
-        self.assertIn("SHOULD support none and RS256", str(cm.exception))
 
     def test_validate_request_object_encryption_alg_values_supported(self):
         self._call_validate_array(
@@ -119,7 +112,7 @@ class OpenIDProviderMetadataTest(unittest.TestCase):
         self._call_validate_array("claim_types_supported", ["normal"])
         self._call_contains_invalid_value("claim_types_supported", ["invalid"])
         metadata = OpenIDProviderMetadata()
-        self.assertEqual(metadata.claim_types_supported, ["normal"])
+        assert metadata.claim_types_supported == ["normal"]
 
     def test_validate_claims_supported(self):
         self._call_validate_array("claims_supported", ["sub"])
@@ -145,12 +138,12 @@ class OpenIDProviderMetadataTest(unittest.TestCase):
 
         metadata = OpenIDProviderMetadata()
         _validate(metadata)
-        self.assertEqual(getattr(metadata, key), default_value)
+        assert getattr(metadata, key) == default_value
 
         metadata = OpenIDProviderMetadata({key: "str"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="MUST be boolean"):
             _validate(metadata)
-        self.assertIn("MUST be boolean", str(cm.exception))
+
         metadata = OpenIDProviderMetadata({key: True})
         _validate(metadata)
 
@@ -160,17 +153,16 @@ class OpenIDProviderMetadataTest(unittest.TestCase):
 
         metadata = OpenIDProviderMetadata()
         if required:
-            with self.assertRaises(ValueError) as cm:
+            with pytest.raises(ValueError, match=f'"{key}" is required'):
                 _validate(metadata)
-            self.assertEqual(f'"{key}" is required', str(cm.exception))
+
         else:
             _validate(metadata)
 
         # not array
         metadata = OpenIDProviderMetadata({key: "foo"})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match="JSON array"):
             _validate(metadata)
-        self.assertIn("JSON array", str(cm.exception))
 
         # valid
         metadata = OpenIDProviderMetadata({key: valid_value})
@@ -178,6 +170,5 @@ class OpenIDProviderMetadataTest(unittest.TestCase):
 
     def _call_contains_invalid_value(self, key, invalid_value):
         metadata = OpenIDProviderMetadata({key: invalid_value})
-        with self.assertRaises(ValueError) as cm:
+        with pytest.raises(ValueError, match=f'"{key}" contains invalid values'):
             getattr(metadata, "validate_" + key)()
-        self.assertEqual(f'"{key}" contains invalid values', str(cm.exception))
