@@ -1,6 +1,10 @@
-from django.db.models import Model, CharField, TextField
-from django.db.models import ForeignKey, CASCADE
 from django.contrib.auth.models import User
+from django.db.models import CASCADE
+from django.db.models import CharField
+from django.db.models import ForeignKey
+from django.db.models import Model
+from django.db.models import TextField
+
 from tests.util import read_file_path
 
 
@@ -8,7 +12,7 @@ class Client(Model):
     user = ForeignKey(User, on_delete=CASCADE)
     client_id = CharField(max_length=48, unique=True, db_index=True)
     client_secret = CharField(max_length=48, blank=True)
-    default_redirect_uri = TextField(blank=False, default='')
+    default_redirect_uri = TextField(blank=False, default="")
 
     def get_default_redirect_uri(self):
         return self.default_redirect_uri
@@ -17,7 +21,7 @@ class Client(Model):
         return self.client_secret
 
     def get_rsa_public_key(self):
-        return read_file_path('rsa_public.pem')
+        return read_file_path("rsa_public.pem")
 
 
 class TokenCredential(Model):
