@@ -35,9 +35,9 @@ class PasswordTest(TestCase):
             data={"grant_type": "client_credentials"},
         )
         resp = server.create_token_response(request)
-        self.assertEqual(resp.status_code, 401)
+        assert resp.status_code == 401
         data = json.loads(resp.content)
-        self.assertEqual(data["error"], "invalid_client")
+        assert data["error"] == "invalid_client"
 
         request = self.factory.post(
             "/oauth/token",
@@ -45,9 +45,9 @@ class PasswordTest(TestCase):
             HTTP_AUTHORIZATION=self.create_basic_auth("invalid", "secret"),
         )
         resp = server.create_token_response(request)
-        self.assertEqual(resp.status_code, 401)
+        assert resp.status_code == 401
         data = json.loads(resp.content)
-        self.assertEqual(data["error"], "invalid_client")
+        assert data["error"] == "invalid_client"
 
     def test_invalid_scope(self):
         server = self.create_server()
@@ -59,9 +59,9 @@ class PasswordTest(TestCase):
             HTTP_AUTHORIZATION=self.create_basic_auth("client", "secret"),
         )
         resp = server.create_token_response(request)
-        self.assertEqual(resp.status_code, 400)
+        assert resp.status_code == 400
         data = json.loads(resp.content)
-        self.assertEqual(data["error"], "invalid_scope")
+        assert data["error"] == "invalid_scope"
 
     def test_invalid_request(self):
         server = self.create_server()
@@ -72,9 +72,9 @@ class PasswordTest(TestCase):
             HTTP_AUTHORIZATION=self.create_basic_auth("client", "secret"),
         )
         resp = server.create_token_response(request)
-        self.assertEqual(resp.status_code, 400)
+        assert resp.status_code == 400
         data = json.loads(resp.content)
-        self.assertEqual(data["error"], "unsupported_grant_type")
+        assert data["error"] == "unsupported_grant_type"
 
     def test_unauthorized_client(self):
         server = self.create_server()
@@ -85,9 +85,9 @@ class PasswordTest(TestCase):
             HTTP_AUTHORIZATION=self.create_basic_auth("client", "secret"),
         )
         resp = server.create_token_response(request)
-        self.assertEqual(resp.status_code, 400)
+        assert resp.status_code == 400
         data = json.loads(resp.content)
-        self.assertEqual(data["error"], "unauthorized_client")
+        assert data["error"] == "unauthorized_client"
 
     def test_authorize_token(self):
         server = self.create_server()
@@ -98,6 +98,6 @@ class PasswordTest(TestCase):
             HTTP_AUTHORIZATION=self.create_basic_auth("client", "secret"),
         )
         resp = server.create_token_response(request)
-        self.assertEqual(resp.status_code, 200)
+        assert resp.status_code == 200
         data = json.loads(resp.content)
-        self.assertIn("access_token", data)
+        assert "access_token" in data
