@@ -18,8 +18,36 @@ class User(db.Model):
     def check_password(self, password):
         return password != "wrong"
 
-    def generate_user_info(self, scopes):
-        profile = {"sub": str(self.id), "name": self.username}
+    def generate_user_info(self, scopes=None):
+        profile = {
+            "sub": str(self.id),
+            "name": self.username,
+            "given_name": "Jane",
+            "family_name": "Doe",
+            "middle_name": "Middle",
+            "nickname": "Jany",
+            "preferred_username": "j.doe",
+            "profile": "https://example.com/janedoe",
+            "picture": "https://example.com/janedoe/me.jpg",
+            "website": "https://example.com",
+            "email": "janedoe@example.com",
+            "email_verified": True,
+            "gender": "female",
+            "birthdate": "2000-12-01",
+            "zoneinfo": "Europe/Paris",
+            "locale": "fr-FR",
+            "phone_number": "+1 (425) 555-1212",
+            "phone_number_verified": False,
+            "address": {
+                "formatted": "742 Evergreen Terrace, Springfield",
+                "street_address": "742 Evergreen Terrace",
+                "locality": "Springfield",
+                "region": "Unknown",
+                "postal_code": "1245",
+                "country": "USA",
+            },
+            "updated_at": 1745315119,
+        }
         return UserInfo(profile)
 
 
@@ -46,6 +74,12 @@ class Token(db.Model, OAuth2TokenMixin):
     def is_refresh_token_active(self):
         return not self.refresh_token_revoked_at
 
+    def get_client(self):
+        return db.session.query(Client).filter_by(client_id=self.client_id).one()
+
+    def get_user(self):
+        return self.user
+
 
 class CodeGrantMixin:
     def query_authorization_code(self, code, client):
@@ -68,20 +102,22 @@ def save_authorization_code(code, request):
     auth_code = AuthorizationCode(
         code=code,
         client_id=client.client_id,
-        redirect_uri=request.redirect_uri,
-        scope=request.scope,
-        nonce=request.data.get("nonce"),
+        redirect_uri=request.payload.redirect_uri,
+        scope=request.payload.scope,
+        nonce=request.payload.data.get("nonce"),
         user_id=request.user.id,
-        code_challenge=request.data.get("code_challenge"),
-        code_challenge_method=request.data.get("code_challenge_method"),
+        code_challenge=request.payload.data.get("code_challenge"),
+        code_challenge_method=request.payload.data.get("code_challenge_method"),
+        acr="urn:mace:incommon:iap:silver",
+        amr="pwd otp",
     )
     db.session.add(auth_code)
     db.session.commit()
     return auth_code
 
 
-def exists_nonce(nonce, req):
+def exists_nonce(nonce, request):
     exists = AuthorizationCode.query.filter_by(
-        client_id=req.client_id, nonce=nonce
+        client_id=request.payload.client_id, nonce=nonce
     ).first()
     return bool(exists)
