@@ -1,3 +1,5 @@
+import time
+
 from flask import current_app
 from flask import json
 
@@ -51,10 +53,12 @@ class BaseTestCase(TestCase):
             }
         )
 
-    def prepare_data(self):
+    def prepare_data(self, require_nonce=False):
         self.config_app()
         server = create_authorization_server(self.app)
-        server.register_grant(AuthorizationCodeGrant, [OpenIDCode()])
+        server.register_grant(
+            AuthorizationCodeGrant, [OpenIDCode(require_nonce=require_nonce)]
+        )
 
         user = User(username="foo")
         db.session.add(user)
@@ -80,6 +84,7 @@ class BaseTestCase(TestCase):
 class OpenIDCodeTest(BaseTestCase):
     def test_authorize_token(self):
         self.prepare_data()
+        auth_request_time = time.time()
         rv = self.client.post(
             "/oauth/authorize",
             data={
@@ -91,10 +96,10 @@ class OpenIDCodeTest(BaseTestCase):
                 "user_id": "1",
             },
         )
-        self.assertIn("code=", rv.location)
+        assert "code=" in rv.location
 
         params = dict(url_decode(urlparse.urlparse(rv.location).query))
-        self.assertEqual(params["state"], "bar")
+        assert params["state"] == "bar"
 
         code = params["code"]
         headers = self.create_basic_header("code-client", "code-secret")
@@ -108,8 +113,8 @@ class OpenIDCodeTest(BaseTestCase):
             headers=headers,
         )
         resp = json.loads(rv.data)
-        self.assertIn("access_token", resp)
-        self.assertIn("id_token", resp)
+        assert "access_token" in resp
+        assert "id_token" in resp
 
         claims = jwt.decode(
             resp["id_token"],
@@ -118,6 +123,9 @@ class OpenIDCodeTest(BaseTestCase):
             claims_options={"iss": {"value": "Authlib"}},
         )
         claims.validate()
+        assert claims["auth_time"] >= int(auth_request_time)
+        assert claims["acr"] == "urn:mace:incommon:iap:silver"
+        assert claims["amr"] == ["pwd", "otp"]
 
     def test_pure_code_flow(self):
         self.prepare_data()
@@ -132,10 +140,10 @@ class OpenIDCodeTest(BaseTestCase):
                 "user_id": "1",
             },
         )
-        self.assertIn("code=", rv.location)
+        assert "code=" in rv.location
 
         params = dict(url_decode(urlparse.urlparse(rv.location).query))
-        self.assertEqual(params["state"], "bar")
+        assert params["state"] == "bar"
 
         code = params["code"]
         headers = self.create_basic_header("code-client", "code-secret")
@@ -149,8 +157,25 @@ class OpenIDCodeTest(BaseTestCase):
             headers=headers,
         )
         resp = json.loads(rv.data)
-        self.assertIn("access_token", resp)
-        self.assertNotIn("id_token", resp)
+        assert "access_token" in resp
+        assert "id_token" not in resp
+
+    def test_require_nonce(self):
+        self.prepare_data(require_nonce=True)
+        rv = self.client.post(
+            "/oauth/authorize",
+            data={
+                "response_type": "code",
+                "client_id": "code-client",
+                "user_id": "1",
+                "state": "bar",
+                "scope": "openid profile",
+                "redirect_uri": "https://a.b",
+            },
+        )
+        params = dict(url_decode(urlparse.urlparse(rv.location).query))
+        assert params["error"] == "invalid_request"
+        assert params["error_description"] == "Missing 'nonce' in request."
 
     def test_nonce_replay(self):
         self.prepare_data()
@@ -164,10 +189,10 @@ class OpenIDCodeTest(BaseTestCase):
             "redirect_uri": "https://a.b",
         }
         rv = self.client.post("/oauth/authorize", data=data)
-        self.assertIn("code=", rv.location)
+        assert "code=" in rv.location
 
         rv = self.client.post("/oauth/authorize", data=data)
-        self.assertIn("error=", rv.location)
+        assert "error=" in rv.location
 
     def test_prompt(self):
         self.prepare_data()
@@ -181,19 +206,37 @@ class OpenIDCodeTest(BaseTestCase):
         ]
         query = url_encode(params)
         rv = self.client.get("/oauth/authorize?" + query)
-        self.assertEqual(rv.data, b"login")
+        assert rv.data == b"login"
 
         query = url_encode(params + [("user_id", "1")])
         rv = self.client.get("/oauth/authorize?" + query)
-        self.assertEqual(rv.data, b"ok")
+        assert rv.data == b"ok"
 
         query = url_encode(params + [("prompt", "login")])
         rv = self.client.get("/oauth/authorize?" + query)
-        self.assertEqual(rv.data, b"login")
+        assert rv.data == b"login"
 
         query = url_encode(params + [("user_id", "1"), ("prompt", "login")])
         rv = self.client.get("/oauth/authorize?" + query)
-        self.assertEqual(rv.data, b"login")
+        assert rv.data == b"login"
+
+    def test_prompt_none_not_logged(self):
+        self.prepare_data()
+        params = [
+            ("response_type", "code"),
+            ("client_id", "code-client"),
+            ("state", "bar"),
+            ("nonce", "abc"),
+            ("scope", "openid profile"),
+            ("redirect_uri", "https://a.b"),
+            ("prompt", "none"),
+        ]
+        query = url_encode(params)
+        rv = self.client.get("/oauth/authorize?" + query)
+
+        params = dict(url_decode(urlparse.urlparse(rv.location).query))
+        assert params["error"] == "login_required"
+        assert params["state"] == "bar"
 
 
 class RSAOpenIDCodeTest(BaseTestCase):
@@ -223,10 +266,10 @@ class RSAOpenIDCodeTest(BaseTestCase):
                 "user_id": "1",
             },
         )
-        self.assertIn("code=", rv.location)
+        assert "code=" in rv.location
 
         params = dict(url_decode(urlparse.urlparse(rv.location).query))
-        self.assertEqual(params["state"], "bar")
+        assert params["state"] == "bar"
 
         code = params["code"]
         headers = self.create_basic_header("code-client", "code-secret")
@@ -240,8 +283,8 @@ class RSAOpenIDCodeTest(BaseTestCase):
             headers=headers,
         )
         resp = json.loads(rv.data)
-        self.assertIn("access_token", resp)
-        self.assertIn("id_token", resp)
+        assert "access_token" in resp
+        assert "id_token" in resp
 
         claims = jwt.decode(
             resp["id_token"],
